==> quasar-1.5.11.jar: META-INF/resources/webjars/quasar/1.5.11/icon-set/eva-icons.js <==
export default {
  name: 'eva-icons',
  type: {
    positive: 'eva-checkmark-circle-2',
    negative: 'eva-alert-triangle',
    info: 'eva-info',
    warning: 'eva-alert-circle-outline'
  },
  arrow: {
    up: 'eva-arrow-upward-outline',
    right: 'eva-arrow-forward-outline',
    down: 'eva-arrow-downward-outline',
    left: 'eva-arrow-back-outline',
    dropdown: 'eva-chevron-down'
  },
  chevron: {
    left: 'eva-arrow-ios-back-outline',
    right: 'eva-arrow-ios-forward-outline'
  },
  colorPicker: {
    spectrum: 'eva-color-picker-outline',
    tune: 'eva-options-2-outline',
    palette: 'eva-pantone-outline'
  },
  pullToRefresh: {
    icon: 'eva-refresh-outline'
  },
  carousel: {
    left: 'eva-arrow-ios-back-outline',
    right: 'eva-arrow-ios-forward-outline',
    navigationIcon: 'eva-radio-button-on',
    thumbnails: 'eva-image-outline'
  },
  chip: {
    remove: 'eva-close',
    selected: 'eva-checkmark'
  },
  datetime: {
    arrowLeft: 'eva-arrow-ios-back-outline',
    arrowRight: 'eva-arrow-ios-forward-outline',
    now: 'eva-clock-outline',
    today: 'eva-calendar-outline'
  },
  editor: {
    bold: 'format_bold',
    italic: 'format_italic',
    strikethrough: 'strikethrough_s',
    underline: 'format_underlined',
    unorderedList: 'format_list_bulleted',
    orderedList: 'format_list_numbered',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'link',
    toggleFullscreen: 'fullscreen',
    quote: 'format_quote',
    left: 'format_align_left',
    center: 'format_align_center',
    right: 'format_align_right',
    justify: 'format_align_justify',
    print: 'print',
    outdent: 'format_indent_decrease',
    indent: 'format_indent_increase',
    removeFormat: 'format_clear',
    formatting: 'text_format',
    fontSize: 'format_size',
    align: 'format_align_left',
    hr: 'remove',
    undo: 'undo',
    redo: 'redo',
    heading: 'format_size',
    code: 'code',
    size: 'format_size',
    font: 'font_download',
    viewSource: 'eva-code'
  },
  expansionItem: {
    icon: 'eva-arrow-ios-downward-outline',
    denseIcon: 'eva-chevron-down'
  },
  fab: {
    icon: 'eva-plus-outline',
    activeIcon: 'eva-close'
  },
  field: {
    clear: 'eva-close-circle',
    error: 'eva-alert-circle'
  },
  pagination: {
    first: 'eva-arrowhead-left-outline',
    prev: 'eva-arrow-ios-back-outline',
    next: 'eva-arrow-ios-forward-outline',
    last: 'eva-arrowhead-right-outline'
  },
  rating: {
    icon: 'eva-star'
  },
  stepper: {
    done: 'eva-checkmark',
    active: 'eva-edit',
    error: 'eva-alert-triangle'
  },
  tabs: {
    left: 'eva-arrow-ios-back-outline',
    right: 'eva-arrow-ios-forward-outline',
    up: 'eva-arrow-ios-upward-outline',
    down: 'eva-arrow-ios-downward-outline'
  },
  table: {
    arrowUp: 'eva-arrow-upward',
    warning: 'eva-alert-triangle',
    prevPage: 'eva-arrow-ios-back-outline',
    nextPage: 'eva-arrow-ios-forward-outline'
  },
  tree: {
    icon: 'eva-arrow-right'
  },
  uploader: {
    done: 'eva-checkmark',
    clear: 'eva-close',
    add: 'eva-plus-square',
    upload: 'eva-cloud-upload',
    removeQueue: 'eva-slash',
    removeUploaded: 'eva-done-all'
  }
}

==> quasar-1.9.4.jar: META-INF/resources/webjars/quasar/1.9.4/icon-set/eva-icons.js <==
export default {
  name: 'eva-icons',
  type: {
    positive: 'eva-checkmark-circle-2',
    negative: 'eva-alert-triangle',
    info: 'eva-info',
    warning: 'eva-alert-circle-outline'
  },
  arrow: {
    up: 'eva-arrow-upward-outline',
    right: 'eva-arrow-forward-outline',
    down: 'eva-arrow-downward-outline',
    left: 'eva-arrow-back-outline',
    dropdown: 'eva-chevron-down'
  },
  chevron: {
    left: 'eva-arrow-ios-back-outline',
    right: 'eva-arrow-ios-forward-outline'
  },
  colorPicker: {
    spectrum: 'eva-color-picker-outline',
    tune: 'eva-options-2-outline',
    palette: 'eva-pantone-outline'
  },
  pullToRefresh: {
    icon: 'eva-refresh-outline'
  },
  carousel: {
    left: 'eva-arrow-ios-back-outline',
    right: 'eva-arrow-ios-forward-outline',
    up: 'eva-arrow-ios-upward-outline',
    down: 'eva-arrow-ios-downward-outline',
    navigationIcon: 'eva-shield'
  },
  chip: {
    remove: 'eva-close',
    selected: 'eva-checkmark'
  },
  datetime: {
    arrowLeft: 'eva-arrow-ios-back-outline',
    arrowRight: 'eva-arrow-ios-forward-outline',
    now: 'eva-clock-outline',
    today: 'eva-calendar-outline'
  },
  editor: {
    bold: 'format_bold',
    italic: 'format_italic',
    strikethrough: 'strikethrough_s',
    underline: 'format_underlined',
    unorderedList: 'format_list_bulleted',
    orderedList: 'format_list_numbered',
    subscript: 'vertical_align_bottom',
    superscript: 'vertical_align_top',
    hyperlink: 'link',
    toggleFullscreen: 'fullscreen',
    quote: 'format_quote',
    left: 'format_align_left',
    center: 'format_align_center',
    right: 'format_align_right',
    justify: 'format_align_justify',
    print: 'print',
    outdent: 'format_indent_decrease',
    indent: 'format_indent_increase',
    removeFormat: 'format_clear',
    formatting: 'text_format',
    fontSize: 'format_size',
    align: 'format_align_left',
    hr: 'remove',
    undo: 'undo',
    redo: 'redo',
    heading: 'format_size',
    code: 'code',
    size: 'format_size',
    font: 'font_download',
    viewSource: 'eva-code'
  },
  expansionItem: {
    icon: 'eva-arrow-ios-downward-outline',
    denseIcon: 'eva-chevron-down'
  },
  fab: {
    icon: 'eva-plus-outline',
    activeIcon: 'eva-close'
  },
  field: {
    clear: 'eva-close-circle',
    error: 'eva-alert-circle'
  },
  pagination: {
    first: 'eva-arrowhead-left-outline',
    prev: 'eva-arrow-ios-back-outline',
    next: 'eva-arrow-ios-forward-outline',
    last: 'eva-arrowhead-right-outline'
  },
  rating: {
    icon: 'eva-star'
  },
  stepper: {
    done: 'eva-checkmark',
    active: 'eva-edit',
    error: 'eva-alert-triangle'
  },
  tabs: {
    left: 'eva-arrow-ios-back-outline',
    right: 'eva-arrow-ios-forward-outline',
    up: 'eva-arrow-ios-upward-outline',
    down: 'eva-arrow-ios-downward-outline'
  },
  table: {
    arrowUp: 'eva-arrow-upward',
    warning: 'eva-alert-triangle',
    prevPage: 'eva-arrow-ios-back-outline',
    nextPage: 'eva-arrow-ios-forward-outline'
  },
  tree: {
    icon: 'eva-arrow-right'
  },
  uploader: {
    done: 'eva-checkmark',
    clear: 'eva-close',
    add: 'eva-plus-square',
    upload: 'eva-cloud-upload',
    removeQueue: 'eva-slash',
    removeUploaded: 'eva-done-all'
  }
}
